/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EnvNamingEvent.java 4310 2008-11-13 09:50:55Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.event.naming;

import org.ow2.easybeans.api.Factory;
import org.ow2.easybeans.deployment.metadata.ejbjar.EasyBeansEjbJarClassMetadata;

import javax.naming.Context;

/**
 * An EnvNamingEvent is an IEvent fired/dispatched during bean's context building phase.
 * @author Guillaume Sauthier
 */
public class EnvNamingEvent extends CompNamingEvent {

    /**
     * Additional metadatas.
     */
    private EasyBeansEjbJarClassMetadata beanMetadata = null;

    /**
     * The default constructor.
     *
     * @param source The event source.
     * @param context the target Context
     * @param factory the EJB factory
     * @param beanMetadata bean related metadata
     */
    public EnvNamingEvent(final String source,
                          final Context context,
                          final Factory<?, ?> factory,
                          final EasyBeansEjbJarClassMetadata beanMetadata) {
        super(source, context, factory);
        this.beanMetadata = beanMetadata;
    }

    /**
     * @return the EJB associated metadatas.
     */
    public EasyBeansEjbJarClassMetadata getBeanMetadata() {
        return beanMetadata;
    }
}
