/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DirectoryRemote.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.mavenplugin.examples.directoryexploded;

import java.util.ArrayList;

/**
 * Remote interface for directory bean.
 * @author julien Blais
 */
public interface DirectoryRemote {

    /**
     * creates a new session instance and an attached directory.
     * @param userName the name of the client
     * @param passwd the password of the client
     * @return true if a session has been created
     */
    boolean create(final String userName, final String passwd);

    /**
     * connect a client to his directory.
     * @param userName the name of the client
     * @param passwd the password of the client
     * @return true if the client is connected
     */
    boolean connect(final String userName, final String passwd);

    /**
     * gets the list of person in the directory.
     * @return the list
     */
    ArrayList getList();

    /**
     * add a person with some informations in the directory.
     * @param firstName of the person to add
     * @param lastName of the person to add
     * @param adress of the person to add
     * @param phone of the person to add
     */
    void add(final String firstName, final String lastName, final String adress, final String phone);

    /**
     * remove a person from directory.
     * @param firstName the first name of the person
     * @param phone the phone number
     */
    void remove(final String firstName, final String phone);
    
    /**
     * get the phone number of a person.
     * @param firstName of the searched person
     * @param lastName of the searched person
     * @return the phone number of the person
     * @throws java.lang.Exception if no person has name <i>firstName</i> in the directory
     */
    String getPhoneNumber(final String firstName, final String lastName) throws Exception;
}
