/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StatefulCalcRemote.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.mavenplugin.examples.calculator;

/**
 * Interface of the calculator stateful bean.
 * @author Julien Blais
 */
public interface StatefulCalcRemote {

    /**
     * Set the initial value of the calculator.
     * @param initValue the initial value of the calculator
     */
    void initial(final int initValue);

    /**
     * Add to the current value.
     * @param toAdd the value to add
     */
    void add(final int toAdd);

    /**
     * Delete from the current value.
     * @param toDel the value to delete
     */
    void del(final int toDel);

    /**
     * Divide the current value.
     * @param toDiv the value used to divide
     */
    void div(final int toDiv);

    /**
     * Multiply the current value.
     * @param toMul the value used to multipy
     */
    void mul(final int toMul);

    /**
     * Return the value of the calculator.
     * @return the current value of the calculator
     */
    int result();
    
}
